---------------------------
-- lets simplify a bit..
---------------------------
local gf = Glance.Functions
local gv = Glance.Variables
local ga = Glance.Arrays
local gb = Glance.Buttons

---------------------------
-- create the button
---------------------------
gf.AddButton("Emblems","LEFT")
local btn = gb.Emblems
btn.text              = "Emblems"
btn.enabled           = true
btn.events            = {"HONOR_CURRENCY_UPDATE", "KNOWN_CURRENCY_TYPES_UPDATE", "LFG_COMPLETION_REWARD", "PLAYER_MONEY"}
btn.update            = true
btn.tooltip           = true
btn.click             = true
btn.timer5            = true
btn.menu              = true
btn.save.perCharacter = {["DisplayEmblems"] = {}}
local spc = btn.save.perCharacter
btn.save.allowProfile = true

---------------------------
-- locals
---------------------------
local VALOR_CURRENCY_ID = 396
local JUSTICE_CURRENCY_ID = 395
local HONOR_CURRENCY_ID = 392
local CONQUEST_CURRENCY_ID = 390

function gf.Emblems.getCap(id)
	local name, amount, texturePath, earnedThisWeek, weeklyMax, totalMax, isDiscovered = GetCurrencyInfo(id)
	if id == VALOR_CURRENCY_ID then 
		weeklyMax = floor(weeklyMax/100)
	end
	totalMax = floor(totalMax/100)
	return {earnedThisWeek, weeklyMax, totalMax}
end

---------------------------
-- update
---------------------------
function gf.Emblems.update()
	local btn = gb.Emblems
	if btn.enabled and gv.loaded then -- loaded keeps it from launching when defined
		local HEX = ga.colors.HEX
		Glance.Debug("function","update","Emblems")
		local hasEmblems = false
		local BT,TMP = HEX.red.."Emblems",""
		for i=1, GetCurrencyListSize() do
			local name, isHeader, isExpanded, isUnused, isWatched, count, icon, itemID, extraCurrencyType = GetCurrencyListInfo(i)
			if spc.DisplayEmblems[name] then
				local ARR = { strsplit(" ", name) }
				if TMP ~= "" then TMP = TMP.."    |r" end
				local capcolor = HEX.green
				if count == 0 then
					capcolor = HEX.red
				end
				if name == "Justice Points" and count == select(3,unpack(gf.Emblems.getCap(JUSTICE_CURRENCY_ID))) then
					capcolor = HEX.red
				end
				if name =="Honor Points" and count == select(3,unpack(gf.Emblems.getCap(HONOR_CURRENCY_ID))) then
					capcolor = HEX.red
				end
				if name == "Valor Points" and count == select(3,unpack(gf.Emblems.getCap(VALOR_CURRENCY_ID))) then
					capcolor = HEX.red
				end
				TMP = TMP..capcolor..count.." |T"..icon..":16|t "
				hasEmblems = true
			end
			if spc.DisplayEmblems["Weekly "..name] then
				if TMP ~= "" then TMP = TMP.."    |r" end
				local capcolor = HEX.green
				if name == "Valor Points" then
					local earned, weekly, total = unpack(gf.Emblems.getCap(VALOR_CURRENCY_ID))
					if earned == weekly then capcolor = HEX.red end
					TMP = TMP..capcolor..earned.."/"..weekly.." |T"..icon..":16|t "
				end
				if name == "Conquest Points" then
					local earned, weekly, total = unpack(gf.Emblems.getCap(CONQUEST_CURRENCY_ID))
					if earned == weekly then capcolor = HEX.red end
					TMP = TMP..capcolor..earned.."/"..weekly.." |T"..icon..":16|t "
				end
				hasEmblems = true
			end
		end
		if hasEmblems then
			BT = TMP
		end
		btn.button:SetText(BT)
		btn.button:SetWidth(btn.button:GetTextWidth())
	end
end

---------------------------
-- tooltip
---------------------------
function gf.Emblems.tooltip()
	Glance.Debug("function","tooltip","Emblems")
	local tooltip = gf.Tooltip
	local hasEmblems = false
	tooltip.Title("Emblems","GLD")
	tooltip.Space()
	for i=1, GetCurrencyListSize() do
		local name, isHeader, isExpanded, isUnused, isWatched, count, icon, itemID, extraCurrencyType = GetCurrencyListInfo(i)
		if isHeader then
			tooltip.Line(name,"GLD")
		else
			local capcolor = "GRN"
			if count == 0 then
				capcolor = "RED"
			end
			if name == "Justice Points" and count == select(3,unpack(gf.Emblems.getCap(JUSTICE_CURRENCY_ID))) then
				capcolor = "RED"
			end
			if name =="Honor Points" and count == select(3,unpack(gf.Emblems.getCap(HONOR_CURRENCY_ID))) then
				capcolor = "RED"
			end
			if name == "Valor Points" and count == select(3,unpack(gf.Emblems.getCap(VALOR_CURRENCY_ID))) then
				capcolor = "RED"
			end
			if spc.DisplayEmblems[name] then
				tooltip.Double(name,count,"LBL",capcolor)
				GameTooltip:AddTexture(icon)
			else
				tooltip.Double(name,count,"WHT",capcolor)
				GameTooltip:AddTexture(icon)
			end
			capcolor = "GRN"
			if name == "Valor Points" then
				local earned, weekly, total = unpack(gf.Emblems.getCap(VALOR_CURRENCY_ID))
				local namecolor = "WHT"
				if earned == weekly then capcolor = "RED" end
				if spc.DisplayEmblems["Weekly "..name] then namecolor = "LBL" end
				tooltip.Double("Weekly "..name,earned.."/"..weekly,namecolor,capcolor)
				GameTooltip:AddTexture(icon)
			end
			if name == "Conquest Points" then
				local earned, weekly, total = unpack(gf.Emblems.getCap(CONQUEST_CURRENCY_ID))
				local namecolor = "WHT"
				if earned == weekly then capcolor = "RED" end
				if spc.DisplayEmblems["Weekly "..name] then namecolor = "LBL" end
				tooltip.Double("Weekly "..name,earned.."/"..weekly,namecolor,capcolor)
				GameTooltip:AddTexture(icon)
			end
			hasEmblems = true
		end
	end
	if not hasEmblems then
		tooltip.Line("|rYou have no emblems","WHT")
	end
	tooltip.Space()
	tooltip.Line("(Click to open the Currency tab.)","WHT")
	tooltip.Wrap("(Right-Click to change Emblem tracking.)","WHT")
end

---------------------------
-- click
---------------------------
function gf.Emblems.click(self, button, down)
	Glance.Debug("function","click","Emblems")
	if button == "LeftButton" then
		ToggleCharacter("TokenFrame")
	end
end

---------------------------
-- menu
---------------------------
function gf.Emblems.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","Emblems")
	local HEX = ga.colors.HEX
	level = level or 1
	if (level == 1) then
		gf.setInfo(nil,true,false,true,nil,HEX.white.."Emblems Options","spacer",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Display","display",level,nil)
	end
	if (level == 2) then
		if UIDROPDOWNMENU_MENU_VALUE == "display" then
			local checked, func
			for i=1, GetCurrencyListSize() do
				local name, isHeader, isExpanded, isUnused, isWatched, count, icon, itemID, extraCurrencyType = GetCurrencyListInfo(i)
				if spc.DisplayEmblems[name]==true then checked = true else checked = false end
				func = function() if spc.DisplayEmblems[name] then spc.DisplayEmblems[name]=false else spc.DisplayEmblems[name]=true end; gf.Emblems.update() end;
				--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func,icon,keepShown,notRadio	
				gf.setInfo(nil,isHeader,false,isHeader,checked,name,name,level,func,icon,true,true)
				if name == "Valor Points" or name == "Conquest Points" then
					if spc.DisplayEmblems["Weekly "..name]==true then checked = true else checked = false end
					func = function() if spc.DisplayEmblems["Weekly "..name] then spc.DisplayEmblems["Weekly "..name]=false else spc.DisplayEmblems["Weekly "..name]=true end; gf.Emblems.update() end;
					--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func,icon,keepShown,notRadio	
					gf.setInfo(nil,isHeader,false,isHeader,checked,"Weekly "..name,"Weekly "..name,level,func,icon,true,true)				
				end
			end
		end
	end
end

---------------------------
-- load on demand
---------------------------
if gv.loaded then
	gf.Enable("Emblems")
end