---------------------------
-- lets simplify a bit..
---------------------------
local gf = Glance.Functions
local gv = Glance.Variables
local ga = Glance.Arrays
local gb = Glance.Buttons

---------------------------
-- create the button
---------------------------
gf.AddButton("Location","RIGHT")
local btn = gb.Location
btn.text              = "Location"
btn.events            = {}
btn.enabled           = true
btn.update            = true
btn.tooltip           = true
btn.click             = true
btn.timer1            = true
btn.menu              = true
btn.save.perAccount   = {["DisplayZone"] = true,["DisplaySubZone"] = true,["DisplayCoords"] = true,["DisplaySpeed"] = true}
local spa = btn.save.perAccount

---------------------------
-- update
---------------------------
function gf.Location.update()
	local btn  = gb.Location
	if btn.enabled and gv.loaded then -- loaded keeps it from launching when defined
		if WorldMapFrame:IsVisible() == nil then
			local HEX = ga.colors.HEX
			local unitx, unity = GetPlayerMapPosition("player")
			local name, subName, sep, display
			local s = ((GetUnitSpeed("Player") / 7) * 100);
			local speed = string.format("%d",s)
			if IsInInstance() then
				name, subName = select(1, GetInstanceInfo()), select(4, GetInstanceInfo())
			else
				name, subName = GetZoneText(), GetSubZoneText()
			end
			name = HEX.darkblue..name
			subName = HEX.lightblue..subName
			sep = "|r- "
			display = ""
			if GetUnitSpeed("Player") ~= 0 and spa.DisplaySpeed then
				display = display.."Speed: "..ga.colors.HEX.green..speed.."% "
				if spa.DisplayZone or spa.DisplaySubZone or spa.DisplayCoords then
					display = display..sep
				end
			end
			if spa.DisplayZone then
				display = display..name.." "
			end
			if spa.DisplaySubZone and subName ~= "" then
				if spa.DisplayZone then
					display = display..sep
				end
				display = display..subName.." "
			end
			if spa.DisplayCoords then
				display = display..string.format(HEX.lightblue.."("..HEX.white.."%d, %d"..HEX.lightblue..")", (unitx * 100), (unity * 100)) 
			end
			btn.button:SetText(display)
			btn.button:SetWidth(btn.button:GetTextWidth())
		end
	end
end

---------------------------
-- tooltip
---------------------------
function gf.Location.tooltip()
	Glance.Debug("function","tooltip","Location")
	local func = gf.Location
	local tooltip = gf.Tooltip
	local unitx, unity = GetPlayerMapPosition("player")
	local speed, groundSpeed, flightSpeed, swimSpeed = GetUnitSpeed("Player")
	local name, subName
	if IsInInstance() then
		name, subName = select(1, GetInstanceInfo()), select(4, GetInstanceInfo())
	else
		name, subName = GetZoneText(), GetSubZoneText()
	end
	tooltip.Title("Location","GLD")
	tooltip.Double("Zone: ", name, "WHT","GRN")
	tooltip.Double("SubZone: ", subName, "WHT","GRN")
	tooltip.Double("Coordinates: ", string.format("(%.2f, %.2f)",(unitx * 100),(unity * 100)), "WHT","GRN")		
	tooltip.Space()
	tooltip.Line("Speed", "GLD")
	tooltip.Double("Ground Speed", func.formatSpeed(groundSpeed).."%","WHT","GRN")
	tooltip.Double("Flight Speed", func.formatSpeed(flightSpeed).."%","WHT","GRN")
	tooltip.Double("Swim Speed", func.formatSpeed(swimSpeed).."%","WHT","GRN")
	tooltip.Space()
	tooltip.Line("(Click to open the world map)","WHT")
	tooltip.Line("(Right-Click to switch display)","WHT")
end

---------------------------
-- click
---------------------------
function gf.Location.click(self, button, down)
	Glance.Debug("function","click","Location")
	if (button == "LeftButton") then 
		ToggleFrame(WorldMapFrame)
	end
end

---------------------------
-- menu
---------------------------
function gf.Location.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","Location")
	local HEX = ga.colors.HEX
	level = level or 1
	if (level == 1) then
		gf.setInfo(nil,true,false,true,nil,HEX.white.."Location Options","spacer",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Display","display",level,nil)
	end
	if (level == 2) then
		if UIDROPDOWNMENU_MENU_VALUE == "display" then
			local checked, func
			if spa.DisplayZone then checked = true else checked = false end
			func = function() if spa.DisplayZone then spa.DisplayZone=false; else spa.DisplayZone=true; end; gf.Location.update() end;--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func,icon,keepShown,notRadio	
			gf.setInfo(nil,false,false,false,checked,"Show Zone","Show Zone",level,func,nil,nil,true)
			if spa.DisplaySubZone then checked = true else checked = false end
			func = function() if spa.DisplaySubZone then spa.DisplaySubZone=false; else spa.DisplaySubZone=true; end; gf.Location.update() end;
			gf.setInfo(nil,false,false,false,checked,"Show SubZone","Show SubZone",level,func,nil,nil,true)
			if spa.DisplayCoords then checked = true else checked = false end
			func = function() if spa.DisplayCoords then spa.DisplayCoords=false; else spa.DisplayCoords=true; end; gf.Location.update() end;
			gf.setInfo(nil,false,false,false,checked,"Show Coordinates","Show Coordinates",level,func,nil,true,true)		
			if spa.DisplaySpeed then checked = true else checked = false end
			func = function() if spa.DisplaySpeed then spa.DisplaySpeed=false; else spa.DisplaySpeed=true; end; gf.Location.update() end;
			gf.setInfo(nil,false,false,false,checked,"Show Speed","Show Speed",level,func,nil,true,true)	
		end
	end
end

---------------------------
-- formatting
---------------------------
function gf.Location.formatSpeed(s)
	local speed = ((s / 7) * 100); -- 7 = 100%
	return string.format("%d",speed)
end

---------------------------
-- load on demand
---------------------------
if gv.loaded then
	gf.Enable("Location")
end